pub struct Provenance {
pub policy: String,
}Expand description
Identifies which policy contributed a requirement.
Carried through merge so findings can name the policies a user would have to disable to drop the requirement.
Fields
policy: StringTrait Implementations
Sourceimpl Clone for Provenance
impl Clone for Provenance
Sourcefn clone(&self) -> Provenance
fn clone(&self) -> Provenance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Provenance
impl Debug for Provenance
impl Eq for Provenance
Sourceimpl Hash for Provenance
impl Hash for Provenance
Sourceimpl Ord for Provenance
impl Ord for Provenance
Sourcefn cmp(&self, other: &Provenance) -> Ordering
fn cmp(&self, other: &Provenance) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Provenance
impl PartialEq for Provenance
Sourceimpl PartialOrd for Provenance
impl PartialOrd for Provenance
impl StructuralPartialEq for Provenance